<?php

namespace Simple\SiteBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Simple\SiteBundle\Entity\Osoba;
use Simple\SiteBundle\Form\OsobaType;

/**
 * Osoba controller.
 *
 * @Route("/osoba")
 */
class OsobaController extends Controller
{
    /**
     * Lists all Osoba entities.
     *
     * @Route("/", name="osoba")
     * @Template()
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entities = $em->getRepository('SimpleSiteBundle:Osoba')->findAll();

        return array('entities' => $entities);
    }

    /**
     * Finds and displays a Osoba entity.
     *
     * @Route("/{id}/show", name="osoba_show")
     * @Template()
     */
    public function showAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('SimpleSiteBundle:Osoba')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Osoba entity.');
        }

        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity'      => $entity,
            'delete_form' => $deleteForm->createView(),        );
    }

    /**
     * Displays a form to create a new Osoba entity.
     *
     * @Route("/new", name="osoba_new")
     * @Template()
     */
    public function newAction()
    {
        $entity = new Osoba();
        $form   = $this->createForm(new OsobaType(), $entity);

        return array(
            'entity' => $entity,
            'form'   => $form->createView()
        );
    }

    /**
     * Creates a new Osoba entity.
     *
     * @Route("/create", name="osoba_create")
     * @Method("post")
     * @Template("SimpleSiteBundle:Osoba:new.html.twig")
     */
    public function createAction()
    {
        $entity  = new Osoba();
        $request = $this->getRequest();
        $form    = $this->createForm(new OsobaType(), $entity);
        $form->bindRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getEntityManager();
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('osoba_show', array('id' => $entity->getId())));
            
        }

        return array(
            'entity' => $entity,
            'form'   => $form->createView()
        );
    }

    /**
     * Displays a form to edit an existing Osoba entity.
     *
     * @Route("/{id}/edit", name="osoba_edit")
     * @Template()
     */
    public function editAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('SimpleSiteBundle:Osoba')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Osoba entity.');
        }

        $editForm = $this->createForm(new OsobaType(), $entity);
        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
     * Edits an existing Osoba entity.
     *
     * @Route("/{id}/update", name="osoba_update")
     * @Method("post")
     * @Template("SimpleSiteBundle:Osoba:edit.html.twig")
     */
    public function updateAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('SimpleSiteBundle:Osoba')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Osoba entity.');
        }

        $editForm   = $this->createForm(new OsobaType(), $entity);
        $deleteForm = $this->createDeleteForm($id);

        $request = $this->getRequest();

        $editForm->bindRequest($request);

        if ($editForm->isValid()) {
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('osoba_edit', array('id' => $id)));
        }

        return array(
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
     * Deletes a Osoba entity.
     *
     * @Route("/{id}/delete", name="osoba_delete")
     * @Method("post")
     */
    public function deleteAction($id)
    {
        $form = $this->createDeleteForm($id);
        $request = $this->getRequest();

        $form->bindRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getEntityManager();
            $entity = $em->getRepository('SimpleSiteBundle:Osoba')->find($id);

            if (!$entity) {
                throw $this->createNotFoundException('Unable to find Osoba entity.');
            }

            $em->remove($entity);
            $em->flush();
        }

        return $this->redirect($this->generateUrl('osoba'));
    }

    private function createDeleteForm($id)
    {
        return $this->createFormBuilder(array('id' => $id))
            ->add('id', 'hidden')
            ->getForm()
        ;
    }
}
